==> ppb-0.8.0rc2.tar.gz: ppb-0.8.0rc2/CONTRIBUTORS.md <==
# PursuedPyBear Contributors


## Maintainers

Name | Email | Twitter |
-----|-------|---------|
[Piper Thunstrom](https://github.com/pathunstrom) | [pathunstrom@gmail.com](mailto:pathunstrom@gmail.com) | [pathunstrom](https://twitter.com/pathunstrom)
[Luna Lunapiena](https://github.com/lunacodes) | [lunacodes@gmail.com](lunacodes@gmail.com) | [lunacodess](https://twitter.com/lunacodess)
[Jamie Bliss](https://github.com/astronouth7303/) | [jamie@ivyleav.es](jamie@ivyleav.es) | [AstraLuma](https://twitter.com/AstraLuma)

Thank you to everyone below for your contributions **(No matter how big or small)!**

## Contributors

Name | Email | Twitter |
---- | ----- | ------- |
[Laura Hampton](https://github.com/lgh2) | [laura@laura-hampton.com](laura@laura-hampton.com) | [incunabulista](https://twitter.com/incunabulista)
[Dimitris Maroulidis](https://github.com/dmaroulidis) | [dimitris@dimitrismaroulidis.com](mailto:dimitris@dimitrismaroulidis.com) | [dmaroulidis](https://twitter.com/dmaroulidis)
[Jenny Li](https://github.com/imjennyli) |
[Andrew Schamp](https://github.com/schamp/) | | [schamp](https://twitter.com/schamp)
[Dillon Omane](https://github.com/dillonko) | [Dillon_KO](dillonko84@gmail.com)
[Nicolas Braud-Santoni](https://nicolas.braud-santoni.eu) | | |
[Zack OConnor](https://github.com/ZackOConnor)| (zackary.oconnor@gmail.com)| |
[Moshe Zadka](https://cobordism.com) | [moshez@zadka.club](moshez@zadka.club) | [moshezadka](https://twitter.com/moshezadka) |
[Daniel Klein](https://github.com/bildzeitung) | [bildzeitung@gmail.com](bildzeitung@gmail.com) | [mrdanielklein](https://twitter.com/bildzeitung)
Halle Jones|HJones@aliacy.com||
[Laura Gutierrez](https://github.com/lauraooq) | [laura.gutierrez@ooqia.com](laura.gutierrez@ooqia.com) | [lauraooq](https://twitter.com/lauraooqia)
[Pamela McA'Nulty](https://github.com/PamelaM) | | [pmcanulty01](https://twitter.com/pmcanulty01)
[Trenton Mason](https://github.com/BubbsTheSupreme) | <trenton.mason14@outlook.com> | [BubbsTheSupreme](https://twitter.com/BubbsTheSupreme)
[Arul Prabakaran](https://github.com/arulprabakaran) | [arul.prabakaran@gmail.com](arul.prabakaran@gmail.com) | [arulpraba](https://twitter.com/arulpraba)
[Calvin Spealman](https://github.com/ironfroggy) | [ironfroggy@gmail.com](ironfroggy@gmail.com) | [@ironfroggy](https://twitter.com/ironfroggy)

==> ppb-0.9.0rc1.tar.gz: ppb-0.9.0rc1/CONTRIBUTORS.md <==
# PursuedPyBear Contributors


## Maintainers

Name | Email | Twitter |
-----|-------|---------|
[Piper Thunstrom](https://github.com/pathunstrom) | [pathunstrom@gmail.com](mailto:pathunstrom@gmail.com) | [pathunstrom](https://twitter.com/pathunstrom)
[Luna Lunapiena](https://github.com/lunacodes) | [lunacodes@gmail.com](lunacodes@gmail.com) | [lunacodess](https://twitter.com/lunacodess)
[Jamie Bliss](https://github.com/astronouth7303/) | [jamie@ivyleav.es](jamie@ivyleav.es) | [AstraLuma](https://twitter.com/AstraLuma)

Thank you to everyone below for your contributions **(No matter how big or small)!**

## Contributors

Name | Email | Twitter |
---- | ----- | ------- |
[Laura Hampton](https://github.com/lgh2) | [laura@laura-hampton.com](laura@laura-hampton.com) | [incunabulista](https://twitter.com/incunabulista)
[Dimitris Maroulidis](https://github.com/dmaroulidis) | [dimitris@dimitrismaroulidis.com](mailto:dimitris@dimitrismaroulidis.com) | [dmaroulidis](https://twitter.com/dmaroulidis)
[Jenny Li](https://github.com/imjennyli) |
[Andrew Schamp](https://github.com/schamp/) | | [schamp](https://twitter.com/schamp)
[Dillon Omane](https://github.com/dillonko) | [Dillon_KO](dillonko84@gmail.com)
[Nicolas Braud-Santoni](https://nicolas.braud-santoni.eu) | | |
[Zack OConnor](https://github.com/ZackOConnor)| (zackary.oconnor@gmail.com)| |
[Moshe Zadka](https://cobordism.com) | [moshez@zadka.club](moshez@zadka.club) | [moshezadka](https://twitter.com/moshezadka) |
[Daniel Klein](https://github.com/bildzeitung) | [bildzeitung@gmail.com](bildzeitung@gmail.com) | [mrdanielklein](https://twitter.com/bildzeitung)
Halle Jones|HJones@aliacy.com||
[Laura Gutierrez](https://github.com/lauraooq) | [laura.gutierrez@ooqia.com](laura.gutierrez@ooqia.com) | [lauraooq](https://twitter.com/lauraooqia)
[Pamela McA'Nulty](https://github.com/PamelaM) | | [pmcanulty01](https://twitter.com/pmcanulty01)
[Trenton Mason](https://github.com/BubbsTheSupreme) | <trenton.mason14@outlook.com> | [BubbsTheSupreme](https://twitter.com/BubbsTheSupreme)
[Arul Prabakaran](https://github.com/arulprabakaran) | [arul.prabakaran@gmail.com](arul.prabakaran@gmail.com) | [arulpraba](https://twitter.com/arulpraba)
[Calvin Spealman](https://github.com/ironfroggy) | [ironfroggy@gmail.com](ironfroggy@gmail.com) | [@ironfroggy](https://twitter.com/ironfroggy)
[Sanket Dasgupta](https://github.com/SanketDG) | [sanketdasgupta@gmail.com](sanketdasgupta@gmail.com) | [@SanketDG](https://twitter.com/SanketDG)
[Serin Delaunay](https://github.com/serin-delaunay) | | [SerinDelaunay](https://twitter.com/SerinDelaunay)
[Nils Müller](https://github.com/shimst3r) | [shimst3r@gmail.com](mailto:shimst3r@gmail.com) | [@shimst3r](https://twitter.com/shimst3r)
